@@ -1,19 +1,16 @@
 class Admin::ProfilesController < Admin::BaseController
 
+  cache_sweeper :blog_sweeper
+
   def index
-    list
-    render :action => 'list'
-  end
 
-  def list
-    @profiles = Profile.find :all
   end
 
   def new
     @profile = Profile.new(params[:profile])
     if request.post? and @profile.save
-      flash[:notice] = 'Profile was successfully created.'
-      redirect_to :action => 'list'
+      flash[:notice] = _('Profile was successfully created.')
+      redirect_to :action => 'index'
     end
   end
 
@@ -21,8 +18,8 @@ class Admin::ProfilesController < Admin::BaseController
     @profile = Profile.find(params[:id])
     @profile.attributes = params[:profile]
     if request.post? and @profile.save
-      flash[:notice] = 'Profile was successfully updated.'
-      redirect_to :action => 'list'
+      flash[:notice] = _('Profile was successfully updated.')
+      redirect_to :action => 'index'
     end
   end
 
@@ -30,7 +27,7 @@ class Admin::ProfilesController < Admin::BaseController
     @profile = Profile.find(params[:id])
     if request.post?
       @profile.destroy if Profile.count > 1
-      redirect_to :action => 'list'
+      redirect_to :action => 'index'
     end
   end
 end
