@@ -1,4 +1,6 @@
 class BackendController < ContentController
+  skip_before_filter :verify_authenticity_token
+  require 'actionwebservice'
   cache_sweeper :blog_sweeper
   session :off
 
@@ -9,5 +11,11 @@ class BackendController < ContentController
   web_service(:mt)          { MovableTypeService.new(self) }
   web_service(:blogger)     { BloggerService.new(self) }
 
-  alias xmlrpc api
+  def xmlrpc
+    api
+  end
+  
+  def api
+    dispatch_web_service_request
+  end
 end
