@@ -2,11 +2,19 @@ class RedirectController < ContentController
   session :off
 
   def redirect
-    r = Redirect.find_by_from_path(params[:from])
+    if (params[:from].first == 'articles')
+      path = request.path.sub('/articles', '')
+      url_root = self.class.relative_url_root
+      path = url_root + path unless url_root.nil?
+      redirect_to path, :status => 301
+      return
+    end
+
+    r = Redirect.find_by_from_path(params[:from].join("/"))
 
     if(r)
       path = r.to_path
-      url_root = request.relative_url_root
+      url_root = self.class.relative_url_root
       path = url_root + path unless url_root.nil? or path[0,url_root.length] == url_root
       redirect_to path, :status => 301
     else
