@@ -6,10 +6,10 @@ class TrackbacksController < FeedbackController
       elsif params[:__mode] == 'rss'
         # Part of the trackback spec... not sure what we should be doing here though.
       else
-          begin  
+          begin
               @trackback =  this_blog.ping_article!(
                 params.merge(:ip => request.remote_ip, :published => true))
-              ""    
+              ""
           rescue ActiveRecord::RecordNotFound, ActiveRecord::StatementInvalid
             throw :error, "Article id #{params[:id]} not found."
           rescue ActiveRecord::RecordInvalid
@@ -29,11 +29,9 @@ class TrackbacksController < FeedbackController
   def get_feedback
     @trackbacks =
       if params[:article_id]
-        this_blog.requested_article(params).published_trackbacks
+        Article.find_by_params_hash(params).published_trackbacks
       else
-        this_blog.published_trackbacks.with_options(this_blog.rss_limit_params) do |t|
-          t.find(:all, :order => 'created_at DESC')
-        end
+        this_blog.published_trackbacks.find(:all, this_blog.rss_limit_params(:order => 'created_at DESC'))
       end
   end
 
