@@ -2,7 +2,7 @@ module Admin::SettingsHelper
   require 'find'
   
   def fetch_langs
-    options = content_tag(:option, "en_US", :value => 'en_US')
+    options = content_tag(:option, "Select lang", :value => 'en_US')
 	Find.find(RAILS_ROOT + "/lang") do |lang|
 	  if lang =~ /\.rb$/
         lang_pattern = File.basename(lang).gsub(".rb", '')
@@ -15,4 +15,9 @@ module Admin::SettingsHelper
 	end
 	options
   end
+  
+  def sweep_cache_link
+    cache = this_blog.cache_option == "caches_action_with_params" ? "sweep" : "sweep_html"
+    link_to _("Sweep cache"), { :controller => "admin/cache",    :action => cache }
+  end
 end
\ No newline at end of file
