@@ -1,6 +1,6 @@
 module SidebarHelper
   def render_sidebars(*sidebars)
-    (sidebars.blank? ? this_blog.sidebars : sidebars).inject('') do |acc, sb|
+    (sidebars.blank? ? Sidebar.find(:all, :order => 'active_position ASC') : sidebars).inject('') do |acc, sb|
       @sidebar = sb
       sb.parse_request(contents, params)
       controller.response.lifetime = sb.lifetime if sb.lifetime
@@ -28,4 +28,16 @@ module SidebarHelper
     end
   end
 
+  def articles?
+    not Article.first.nil?
+  end
+
+  def trackbacks?
+    not Trackback.first.nil?
+  end
+
+  def comments?
+    not Comment.first.nil?
+  end
+
 end
