@@ -2,15 +2,7 @@ module XmlHelper
   def pub_date(time)
     time.rfc822
   end
-
-  def post_title(post)
-    h(post.title)
-  end
-
-  def blog_title
-    this_blog.blog_name || "Unnamed blog"
-  end
-
+  
   def collection_lastmod(collection)
     article_updated = collection.articles.find(:first, :order => 'updated_at DESC')
     article_published = collection.articles.find(:first, :order => 'published_at DESC')
