@@ -17,13 +17,6 @@ class Comment < Feedback
     end
   end
 
-  def notify_user_via_jabber(user)
-    if user.notify_via_jabber?
-      JabberNotify.send_message(user, "New comment", "A new comment was posted to '#{article.title}' on #{blog.blog_name} by #{author}:
-        #{body}", self.html(:body))
-    end
-  end
-
   def interested_users
     users = User.find_boolean(:all, :notify_on_comments)
     self.notify_users = users
