@@ -16,5 +16,8 @@ config.action_controller.perform_caching             = false
 # ActionMailer::Base.deliveries array.
 config.action_mailer.delivery_method = :test
 
+# Disables requets forgery protection
+config.action_controller.allow_forgery_protection    = false 
+
 Migrator.offer_migration_when_available            = false
 require 'ruby-debug'
