@@ -5,22 +5,24 @@ Localization.define('fr_FR') do |l|
   l.store "Publish", "Écrire"
   l.store "Manage", "Gérer"
   l.store "Feedback", "Commentaires"
-  l.store "Design", "Personnaliser"
-  l.store "Users", ["Utilisateur", "Utilisateurs"]
+  l.store "Themes", "Thèmes"
+  l.store "Plugins", "Greffons"
+  l.store "Users", "Utilisateurs"
   l.store "Settings", "Configuration"
   l.store "Things you can do", "Vous pouvez"
-  l.store "with %s Famfamfam iconset %s", "avec %s les icônes Famfamfam %s"
-  
-  #admin/login.rhtml
+  l.store "with %s AER OS XK iconset iconset %s", "avec %s les icônes AER OS XK iconset %s"
+    
+  #accounts/login.rhtml
+  l.store "Administration", "Administration"
   l.store "Username", "Identifiant"
   l.store "Password", "Mot de passe"
   l.store "Login", "Connexion"
-  l.store "Back to the blog", "Retour à votre blog"
+  l.store "Back to ", "Revenir à "
+  l.store "Login unsuccessful", "Échec de la connexion"
+  l.store "Login successful", "Connexion réussie"
 
   # admin/logout.rhtml
-  l.store "You are now logged out of the system", "Vous êtes maintenant déconnecté"
-  l.store "Do you want to go to your blog?", "Souhaitez-vous retourner sur votre blog ?"
-  l.store "Logoff", "Déconnexion"
+  l.store "Successfully logged out", "Vous êtes maintenant déconnecté"
   
   # admin/signup.rhtml
   l.store "Signup", "S'inscrire"
@@ -29,19 +31,23 @@ Localization.define('fr_FR') do |l|
   l.store "Email", "Courriel"
   l.store "Choose password", "Mot de passe"
   l.store "Confirm password", "Confirmez le mot de passe"
+  l.store "Signup successful", "Inscription réussie"
   
   # admin/dashboard/index.rhtml
   l.store "What can you do ?", "Vous pouvez"
-  l.store "Write Post", "Écrire Billet"
-  l.store "Write Page", "Écrire Page"
+  l.store "Write a post", "Écrire un billet"
+  l.store "Write a page", "Écrire une page"
   l.store "Update your profile or change your password", "Mettre votre profil à jour ou changer votre mot de passe"
-  l.store "Change you blog presentation", "Changer l'apparence de votre blog"
+  l.store "Change your blog presentation", "Changer l'apparence de votre blog"
   l.store "Enable plugins", "Ajouter des greffons"
   l.store "Last Comments", "Derniers commentaires"
   l.store "Last posts", "Derniers billets"
   l.store "Most popular", "Billets les plus populaires"
-  l.store "Typo documentation", "Documentation officielle de Typo"
+  l.store "Typo documentation", "Accéder à la documentation officielle de Typo"
   l.store "No comments yet", "Aucun commentaire"
+  l.store "Nothing to show yet", "Rien à déclarer"
+  l.store "No posts yet, why don't you start and write one", "Vous n'avez encore écrit aucun billet, pourquoi ne pas commencer par là"
+  l.store "You have no internet connection", "Vous n'avez pas de connection à internet"
   
   #admin/base/recent_comments.rhtml
   l.store "Recent comments", "Derniers commentaires"
@@ -77,11 +83,10 @@ Localization.define('fr_FR') do |l|
   
   #admin/cache/list.rhtml
   l.store "Cache", "Cache"
-  l.store "There are %d entries in the page cache", ["Une seule page en cache", "%d pages sont actuellement stockées en cache"]
   
   #admin/categories/_categories.rhtml
   l.store "Category title", "Nom de la catégorie"
-  l.store "Articles", ["Billet", "Billets"]
+  l.store "%d Articles", ["Un Billet", "%d Billets"]
   
   #admin/categories/_form.rhtml
   l.store "Name", "Titre"
@@ -91,7 +96,7 @@ Localization.define('fr_FR') do |l|
   l.store "Add category", "Ajouter la catégorie"
   
   #admin/categorie/destroy.rhtml
-  l.store "Categories", ["Catégorie", "Catégories"]
+  l.store "%d categories",  ["Une catégorie", "%d Catégories"]
   l.store "Show this category", "Voir cette catégorie"
   l.store "Delete this category", "Supprimer cette catégorie"
   l.store "Are you sure you want to delete the category ", "Êtes vous certain de vouloir supprimer la catégorie "
@@ -108,7 +113,7 @@ Localization.define('fr_FR') do |l|
   l.store "Reorder", "Trier"
   l.store "Sort alphabetically", "Trier par ordre alphabétique"
   l.store "Manage Articles", "Gérer les billets"
-  l.store "Manage Pages", "Gérer les pages statiques"
+  l.store "Manage Pages", "Gérer les pages"
   l.store "Manage Resources", "Gérer les ressources"
   
   #admin/category/reorder.rhtml
@@ -141,19 +146,25 @@ Localization.define('fr_FR') do |l|
   #admin/comments/new.rhtml
   l.store "Creating comment", "Ajouter un commentaire"
   
-  #admin/content/_articles.rhtml
-  l.store "Posts", "Billets"
-  l.store "Uploads", "Fichier uploadé"
+  #admin/content/list.rhtml
+  l.store "Manage posts", "Administrer les billets"
+  l.store "Manage uploads", "Administrer les pièces jointes"
+  l.store "Manage categories", "Administrer les catégories"
+  l.store "Manage pages", "Administrer les pages"
   l.store "Post title", "Titre du billet"
   l.store "Posted at", "Date de publication"
-  l.store "Comments", ["Commentaire", "Commentaires"]
-  l.store "Trackbacks", ["Rétrolien", "Rétroliens"]
+  l.store "Posted on", "Publié le"
+  l.store "%d Comments", ["Un commentaire", "%d Commentaires"]
+  l.store "%d Trackbacks", ["Un rétrolien", "%d Rétroliens"]
   l.store "View", "Voir"
   l.store "Status", "État"
   l.store "Offline", "Hors ligne"
   l.store "Online", "En ligne"
   l.store "no trackbacks", "aucun rétrolien"
   l.store "no comments", "aucun commentaire"
+  l.store "Posts", "Billets"
+  l.store "Comments", "Commentaires"
+  l.store "Categories", "Catégories"
   
   #admin/content/_attachment.rhtml
   l.store "Remove", "Supprimer"
@@ -163,21 +174,21 @@ Localization.define('fr_FR') do |l|
   #admin/content/_form.rhtml
   l.store "Article Body", "Corps du billet"
   l.store "Post", "Contenu"
-  l.store "Optional extended content", "Contenu étendu optionnel"
-  l.store "Optional Extended Content", "Contenu Étendu Optionnel"
+  l.store "Optional extended content", "Contenu étendu (optionnel)"
   l.store "Article Content", "Contenu du billet"
   l.store "Extended Content", "Contenu étendu"
-  l.store "Tags", ["Mot clé", "Mots clé"]
-  l.store "Save", "Enregistrer"
+  l.store "Tags", "Mots clés"
+  l.store "Save", "Sauver"
   l.store "Article Attachments", "Pièces Jointes"
   l.store "Article Options", "Options du billet"
   l.store "Permalink", "Lien permanent"
   l.store "Allow comments", "Autoriser les commentaires"
   l.store "Allow trackbacks", "Autoriser les rétroliens"
-  l.store "Published", "Publié"
+  l.store "Online", "En ligne"
   l.store "Publish at", "Publié le"
   l.store "Textfilter", "Formatage du texte"
   l.store "Toggle Extended Content", "Afficher le contenu étendu"
+  l.store "These are advanced options. Only experimented users should use them", "Options avancées. À ne modifier que par des utilisateurs expérimentés"
   
   #admin/content/_pages.rhtml
   l.store "Previous page", "Page précédente"
@@ -200,10 +211,6 @@ Localization.define('fr_FR') do |l|
   l.store "Edit Article", "Éditer un billet"
   l.store "View article on your blog", "Voir ce billet sur votre blog"
 
-  #admin/content/new.rhtml
-  l.store "Write a Page", "Écrire une page statique"
-  l.store "Write an Article", "Écrire un billet"
-
   #admin/content/preview.rhtml
   l.store "Posted by", "Publié par"
   
@@ -220,6 +227,16 @@ Localization.define('fr_FR') do |l|
   l.store "Blacklist", "Liste noire"
   l.store "Feedback Search", "Rechercher dans les discussions"
   l.store "Comments and Trackbacks for", "Commentaires et rétroliens pour"
+
+  #admin/feedback/index.html.erb
+  l.store "Limit to ham", "Uniquement les commentaires valides"
+  
+  #admin/feedback/article.html.erb
+  l.store "All comments", "Tous les commentaires"
+
+  #admin/feedback/create
+  l.store "Comment was successfully created.", "Commentaire crée avec succès."
+  l.store "Comment was successfully updated.", "Commentaire mis à jour avec succès."
  
   #admin/general/task
   l.store "Basic settings", "Configuration de base"
@@ -241,7 +258,6 @@ Localization.define('fr_FR') do |l|
   l.store "Blog name", "Titre du blog"
   l.store "Blog subtitle", "Sous-titre du blog"
   l.store "Language", "Langue"
-  l.store "This option let you choose between the simple admin interface or the complete one, displaying much more options and therefore more complicated to use. For advanced users only!", "Cette option permet de choisir entre l'interface d'administration simple ou la complète qui affiche beaucoup plus d'options et qui est donc plus compliqué à utiliser. Uniquement pour les utilisateurs avancés!"
   l.store "Blog URL", "Adresse du blog"
   l.store "Latitude, Longitude", "Latitude, Longitude"
   l.store "Display", "Afficher"
@@ -280,8 +296,6 @@ Localization.define('fr_FR') do |l|
   l.store "Source Email", "Adresse courriel source"
   l.store "Email address used by Typo to send notifications", "Adresse courriel utilisée par Typo pour l'envoi d'alertes"
   l.store "Jabber account", "Compte Jabber"
-  l.store "Jabber account to use when sending Jabber notifications", "Compte jabber à utiliser pour l'envoi d'alertes"
-  l.store "Jabber password", "Mot de passe Jabber"
   l.store "Spam protection", "Protection contre le spam"
   l.store "Enabling spam protection will make typo compare the IP address of posters as well as the contents of their posts against local and remote blacklists. Good defense against spam bots", "La protection contre le spam permettra à typo de comparer l'adresse IP des commentateurs ainsi que le contenu de leurs commentaires avec une liste noire distante"
   l.store "Enable spam protection", "Activer la protection contre le spam"
@@ -297,8 +311,12 @@ Localization.define('fr_FR') do |l|
   l.store "Explicit", "Contenu explicite"
   l.store "Empty Fragment Cache", "Vider le cache"
   l.store "Rebuild cached HTML", "Reconstruire le HTML en cache"
-  l.store "There are %d entries in the cache", ["Une seule page en cache", "%d pages sont actuellement stockées en cache"]
   l.store "days", "jours"
+  l.store "General options", "Options générales"
+  l.store "By default, Typo generates static HTML pages for your posts. However, if you plan to publish posts in the futur, you may want to use semi dynamic caching", "Par défaut, Typo génère des pages HTML statiques. Cependant, si vous prévoyez d'utiliser les fonctionnalités de publication dans le futur, il vous faudra utiliser le cache dynamique"
+  l.store "Use static HTML page caching", "Utiliser le cache statique"
+  l.store "Use semi static caching (default)", "Utiliser le cache dynamique (option par défaut)"
+  l.store "Choose caching methode", "Sélectionnez la méthode de cache"
   
   #admin/general/update_database
   l.store "Database migration", "Mise à jour de la base de données"
@@ -322,7 +340,7 @@ Localization.define('fr_FR') do |l|
   
   #admin/pages/_pages.rhtml
   l.store "Action", "Actions"
-  l.store "Pages","Pages statiques"
+  l.store "Pages","Gérer les pages"
   l.store "Show this page", "Afficher cette page"
   l.store "Are you sure you want to delete the page", "Voulez-vous vraiment effacer cette page"
   l.store "Delete this page", "Supprimer cette page"
@@ -344,7 +362,7 @@ Localization.define('fr_FR') do |l|
   l.store "Key Words", "Mots clé"
   l.store "seperate with spaces", "séparez-les par des espaces"
   l.store "Category", "Catégorie"
-  
+
   #admin/resources/_metadata_edit.rhtml
   l.store "Remove iTunes Metadata", "Supprimer les méta données iTunes"
   l.store "Content Type", "Type de contenu"
@@ -366,7 +384,7 @@ Localization.define('fr_FR') do |l|
 
   #admin/resources/new.rhtml
   l.store "Upload a File to your Site", "Envoyer un fichier sur votre site"
-  l.store "Upload", "Envoyer"
+  l.store "Upload", "Ajouter un fichier joint"
   l.store "Upload a new Resource", "Ajouter une pièce jointe"
   l.store "File", "Fichier"
   
@@ -422,9 +440,16 @@ Localization.define('fr_FR') do |l|
   l.store "See help text for this filter", "Afficher l'aide de ce filtre"
   
   #admin/themes/index.rhtml
-  l.store "Choose a theme", "Choisissez un thème"
+  l.store "Choose theme", "Choisissez un thème"
+  l.store "Theme editor", "Éditeur de thèmes"
   l.store "Activate", "Activer"
   l.store "Active theme", "Thème actif"
+  l.store "You can download third party themes from officially supported %s ", "Vous pouvez télécharger des thèmes officiellement supportés sur %s "
+  l.store "dev 411 Typo themes viewer", "le visualisateur de thèmes de dev411"
+
+  #admin/themes/catalogue.html.erb
+  l.store "Theme catalogue", "Catalogue de thème"
+  l.store "Sorry the theme catalogue is not available", "Désolé le catalogue de thème n'est pas disponible"
   
   #admin/trackbacks/edit.rhtml
   l.store "Trackbacks for", "Rétroliens pour"
@@ -438,9 +463,21 @@ Localization.define('fr_FR') do |l|
   l.store "Jabber", "Jabber"
   l.store "Password Confirmation", "Confirmer le mot de passe"
   l.store "Send notification messages via email", "Envoyer des alertes par courriel"
-  l.store "Send notification messages via jabber", "Envoyer des alertes par Jabber"
   l.store "Send notification messages when new articles are posted", "Envoyer des alertes à la publication de nouveaux billets"
   l.store "Send notification messages when comments are posted", "Envoyer des alertes à la publication de nouveaux commentaires"
+  l.store "Login", "Login"
+  l.store "Profile", "Profil"
+  l.store "Display Name", "Nom affiché"
+  l.store "Email", "Email"
+  l.store "Password", "Mot de passe"
+  l.store "Password confirmation", "Confirmation du mot de passe"
+  l.store "Send notification messages via email", "Envoi de notification des messages par email"
+  l.store "Send notification messages when new articles are posted", "Envoi de notification de messages quand de nouveaux articles sont postés" 
+  l.store "Send notification messages when comments are posted", "Envoi de notification de messages quand des commentaires sont postés"
+
+  #admin/user/new.html.erb
+  l.store "Add User", "Ajout d'utilisateur"
+  l.store "Users", "Utilisateurs"
   
   #admin/user/_user.rhtml
   l.store "Number of Articles", "Nombre de billets"
@@ -464,7 +501,6 @@ Localization.define('fr_FR') do |l|
   #admin/user/show.rhtml
   l.store "User's articles", "Articles publiés par cet utilisateur"
   l.store "Notify via email", "Cet utilisateur reçoit des alertes par courriel"
-  l.store "Notify via jabber", "Cet utilisateur reçoit des alertes par Jabber"
   l.store "Notify on new articles", "Cet utilisateur est alerté à la publication d'un nouveau billet"
   l.store "Notify on new comments", "Cet utilisateur est alerté à la publication d'un nouveau commentaire"
   
@@ -519,10 +555,7 @@ Localization.define('fr_FR') do |l|
   
   #vendor/plugins/archives_sidebar/views/content.rb
   l.store "Archives", "Archives"
-  
-  #vendor/plugins/tags_sidebar/views/content.rb
-  l.store "Tags", "Tags"
-  
+    
   #app/helpers/admin/base_helper.rb
   l.store "Back to overview", "Revenir à la liste"
   l.store "log out", "déconnexion"
@@ -552,4 +585,121 @@ Localization.define('fr_FR') do |l|
   l.store "Content Type was successfully updated.", "Le type du contenu a été mis à jour avec succès."
   l.store "Error occurred while updating Content Type.", "Une erreur est survenue lors de la mise à jour du type du contenu."
   l.store "complete", "complet"
+
+  #app/controller/admin/user_controller.rb
+  l.store "User was successfully updated.", "L'utilisateur a été mis à jour avec succès."
+  l.store "User was successfully created.", "L'utilisateur a été créé avec succès."
+
+
+  
+  # Themes
+  l.store "Home", "Accueil"
+  l.store "About", "À propos"
+  l.store "Designed by %s ported to typo by %s ", "Design par %s porté sous Typo par %s"
+  l.store "Powered by %s", "Propulsé par %s"
+  l.store "Read full article", "Lien permanent"
+  l.store "Search", "Chercher"
+  l.store "Continue reading...", "Lire la suite..."
+  l.store "Posted by", "Publié par"
+  l.store "January", "Janvier"
+  l.store "February", "Février"
+  l.store "March", "Mars"
+  l.store "April", "Avril"
+  l.store "May", "Mai"
+  l.store "June", "Juin"
+  l.store "July", "Juillet"
+  l.store "August", "Août"
+  l.store "September", "Septembre"
+  l.store "October", "Octobre"
+  l.store "November", "Novembre"
+  l.store "December", "Décembre"
+  l.store "This entry was posted on %s", "Ce billet a été posté le %s"
+  l.store "Posted in", "Publié sous"
+  l.store "and %s", "et %s"
+  l.store "Atom feed", "flux Atom"
+  l.store "You can follow any any response to this entry through the %s", "Vous pouvez suivre la discussion autour de cet article via le %s"
+  l.store "You can leave a %s", "Vous pouvez déposer un %s"
+  l.store "or a %s from your own site", "ou un %s depuis votre site"
+  l.store "later", "plus tard"
+  l.store "Leave a comment", "laisser un commentaire"
+  l.store "Name %s", "Votre nom %s"
+  l.store "required", "obligatoire"
+  l.store "Preview", "Prévisualiser "
+  l.store "enabled", "activés"
+  l.store "never displayed", "jamais affiché"
+  l.store "Comments", "Commentaires"
+  l.store "Website", "Votre site"
+  l.store "Textile enabled", "Textile activé"
+  l.store "Markdown enabled", "Markdown activé"
+  l.store "Submit", "Envoyer"
+  l.store "is about to say", "va dire"
+  l.store "Older posts", "Billets précédents"
+  l.store "Use the following link to trackback from your own site", "Utilisez le lien ci-dessous pour envoyer un trackback depuis votre site"
+  l.store "Leave a response", "Réagir à ce billet"
+  l.store "styled width %s", "design %s"
+  l.store "Searching", "Recherche en cours"
+  l.store "permalink", "lien permanent"
+  l.store "Name", "Nom"
+  l.store "leave url/email", "laissez votre url/courriel"
+  l.store "No comments", "Pas de commentaires"
+  l.store "From", "De"
+  l.store "Meta", "Méta"
+  l.store "comment", "commentaire"
+  l.store "comments", "commentaires"
+  l.store "posted in", "publié dans"
+  
+  # Dates 
+  l.store "Mon", "Lun"
+  l.store "Tue", "Mar"
+  l.store "Wed", "Mer"
+  l.store "Thu", "Jeu"  
+  l.store "Fri", "Ven"  
+  l.store "Sat", "Sam"  
+  l.store "Sun", "Dim"
+  l.store "Monday", "Lundi"
+  l.store "Tuesday", "Mardi"
+  l.store "Wednesday", "Mercredi"
+  l.store "Thursday", "Jeudi"  
+  l.store "Friday", "Vendredi"  
+  l.store "Saturday", "Samedi"  
+  l.store "Sunday", "Dimanche"
+  l.store "Jan", "Jan"    
+  l.store "Feb", "Fév"
+  l.store "Mar", "Mars"
+  l.store "Apr", "Avr"
+  l.store "May", "Mai"
+  l.store "Jun", "Juin"
+  l.store "Jul", "Juil"
+  l.store "Aug", "Août"
+  l.store "Sep", "Sept"
+  l.store "Oct", "Oct"
+  l.store "Nov", "Nov"
+  l.store "Dec", "Déc"
+  l.store "January", "janvier"    
+  l.store "February", "février"
+  l.store "March", "mars"
+  l.store "April", "avril"
+  l.store "May", "mai"
+  l.store "June", "juin"
+  l.store "July", "juillet"
+  l.store "August", "août"
+  l.store "September", "septembre"
+  l.store "October", "octobre"
+  l.store "November", "novembre"
+  l.store "December", "décembre"
+  l.store "%%a, %%d %%b %%Y %%H:%%M:%%S GMT", Proc.new {|date|
+     sprintf( date.strftime("%%s %d %%s %Y %H:%M:%S GMT"), _(date.strftime("%a")), _(date.strftime("%b")).downcase )
+  }
+  l.store "%%d. %%b", Proc.new {|date|
+     sprintf( date.strftime("%d. %%s"), _(date.strftime("%b")).downcase )
+  }
+  l.store "Original article writen by", "Article original écrit par" 
+  l.store "and published on", "et publié sur"
+  l.store "direct link to this article", "lien direct vers cet article" 
+  l.store "If you are reading this article elsewhere than", "Si vous lisez cet article ailleurs que sur" 
+  l.store "it has been illegally reproduced and without proper authorization", "c'est qu'il a été reproduit illégalement et sans autorisation"
+  l.store "This will display", "Cela affichera"
+  l.store "at the bottom of each of your post in the RSS feed", "en bas de chacun de vos articles sur le flux RSS"
+  l.store "for", "pour"
+  l.store "everything about", "tout sur"
 end
