@@ -1,8 +1,6 @@
 require File.dirname(__FILE__) + '/../spec_helper'
 
 describe "Given the first Blog fixture" do
-  fixtures :blogs, :contents, :sidebars
-
   before(:each) { @blog = blogs(:default) }
 
   it ":blog_name == 'test blog'" do
@@ -22,7 +20,27 @@ describe "Given the first Blog fixture" do
     @blog.url_for(:controller => 'articles', :action => 'read', :id => 1).should == 'http://myblog.net/articles/read/1'
   end
 
-  it "blog has one sidebar" do
-    @blog.should have(1).sidebars
+  it "should be the only blog allowed" do
+    Blog.new.should_not be_valid
+  end
+end
+
+describe "The default blog" do
+  it "should pick up updates after a cache clear" do
+    a = Blog.default
+    CachedModel.cache_reset
+    b = blogs(:default)
+    b.blog_name = "some other name"
+    c = Blog.default
+    c.blog_name.should == "some other name"
+  end
+end
+
+
+describe "Given no blogs" do
+  before(:each)  { Blog.destroy_all }
+
+  it "should allow the creation of a valid default blog" do
+    Blog.new.should be_valid
   end
 end
